[![PyPi Release](https://img.shields.io/pypi/v/maestral-gui.svg)](https://pypi.org/project/maestral-gui/)
[![Pyversions](https://img.shields.io/pypi/pyversions/maestral-gui.svg)](https://pypi.org/pypi/maestral-gui/)

# Maestral GUI <img src="https://raw.githubusercontent.com/SamSchott/maestral-dropbox/develop/maestral/resources/maestral.png" align="right" title="Maestral" width="110" height="110">

A user interface for the [Maestral Daemon](https://www.github.com/samschott/maestral-dropbox).
This package currently install [maestral-cocoa](https://www.github.com/samschott/maestral-cocoa)
or [maestral-qt](https://www.github.com/samschott/maestral-cocoa), depending on the
platform, and mainly serves to reserve the namespace on PyPI.
